@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: binary-tagged
-version: 0.1.3.0
-id: binary-tagged-0.1.3.0-9f28b372dda874f24a9b6bac38e19756
-key: binar_6hGydwdeaeZAINYzAlGrzf
+version: 0.1.3.1
+id: binary-tagged-0.1.3.1-fe2a180b67aea32197c73b98ed3f4d58
+key: binar_6I64QOaUElr616iey1mYCU
 license: BSD3
 maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
 homepage: https://github.com/phadej/binary-tagged#readme
@@ -16,25 +16,25 @@ exposed: True
 exposed-modules:
     Data.Binary.Tagged
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.0
-library-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.0
-data-dir: /usr/share/arm-linux-ghc-7.10.3/binary-tagged-0.1.3.0
-hs-libraries: HSbinary-tagged-0.1.3.0-6hGydwdeaeZAINYzAlGrzf
+import-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/binary-tagged-0.1.3.1
+hs-libraries: HSbinary-tagged-0.1.3.1-6I64QOaUElr616iey1mYCU
 depends:
     SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
-    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
+    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    generics-sop-0.2.0.0-419d3678c9b0f53a693a7ea2fc8ff7c9
+    generics-sop-0.2.1.0-7239eda8d6e847745310ee1c6aedf3ba
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
     scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
 haddock-html: /usr/share/doc/haskell-binary-tagged/html
